.. _profile_module:

:mod:`cubicweb.pyramid.profile`
===============================

.. automodule:: cubicweb.pyramid.profile

    Views
    -----

    .. autofunction:: ping

    .. autofunction:: cnx

    WSGI
    ----

    .. autofunction:: wsgi_profile

